@@ -6,7 +6,7 @@ Created on Fri Aug  5 17:30:03 2022
 @author: smn06
 """
 
-from visualize import *
+from final_test05.visualize import *
 #function for making the prediction and visualization
 def knn(X_train, X_test, y_train, y_test):
     #importing and fitting the model from sklearn
