@@ -6,7 +6,7 @@ Created on Fri Aug  5 16:02:15 2022
 @author: smn06
 """
 
-from visualize import *
+from final_test05.visualize import *
 
 #function for making the prediction and visualization
 def logistic(X_train, X_test, y_train, y_test):
